@@ -1,12 +1,12 @@
-from andes.core.param import ExtParam, NumParam, IdxParam
-from andes.core.model import Model, ModelData
-from andes.core.var import ExtAlgeb, Algeb
-from andes.core.service import ConstService
-from andes.core.service import BackRef, DeviceFinder
-from andes.core.discrete import Sampling
-from andes.utils.tab import Tab
 from collections import OrderedDict
 
+from andes.core.discrete import Sampling
+from andes.core.model import Model, ModelData
+from andes.core.param import ExtParam, IdxParam, NumParam
+from andes.core.service import BackRef, ConstService, DeviceFinder
+from andes.core.var import Algeb, ExtAlgeb
+from andes.utils.tab import Tab
+
 
 class AreaData(ModelData):
     def __init__(self):
