@@ -1,8 +1,10 @@
 import logging
-from _pydecimal import Decimal, ROUND_DOWN
 from time import time
 
+from decimal import ROUND_DOWN, Decimal
+
 logger = logging.getLogger(__name__)
+_missing = object()
 
 
 def elapsed(t0=0.0):
@@ -91,3 +93,38 @@ def is_interactive():
     import __main__ as main
 
     return not hasattr(main, '__file__') or ipython
+
+
+class cached:
+    """A decorator that converts a function into a lazy property.  The
+    function wrapped is called the first time to retrieve the result
+    and then that calculated result is used the next time you access
+    the value::
+
+        class Foo:
+
+            @cached
+            def foo(self):
+                # calculate something important here
+                return 42
+
+    The class has to have a `__dict__` in order for this property to
+    work.
+    See for details:
+    http://stackoverflow.com/questions/17486104/python-lazy-loading-of-class-attributes
+    """
+
+    def __init__(self, func, name=None, doc=None):
+        self.__name__ = name or func.__name__
+        self.__module__ = func.__module__
+        self.__doc__ = doc or func.__doc__
+        self.func = func
+
+    def __get__(self, obj, type=None):
+        if obj is None:
+            return self
+        value = obj.__dict__.get(self.__name__, _missing)
+        if value is _missing:
+            value = self.func(obj)
+            obj.__dict__[self.__name__] = value
+        return value
